name='chitti'

from chitti.print import pprint, plen, pprint_nl
from chitti.color_text import color_words_in_text
from chitti.sklearn_utilities import plot_confusion_matrix as confusion_matrix
from chitti.list_to_dic import counter, counter_df

